
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.23.10',
    'branch_nick': 'patch-0-Release__1_23_10_preparation',
    'revision_id': '703f0276f2d20e55204c699c0cabf41099246615',
    'revno': 10198
}
